# tunesynctool (formerly Navify)

A Python package and CLI* to transfer music between your local/commercial streaming services. Supports track matching.

*Under development

Tunesynctool supports the following services:
- Spotify
- Deezer
- Any Subsonic-like service (Navidrome, Airsonic, etc.)
- YouTube Music

Support for other services will be added in the future.

## Usage

Install the latest release vie PyPI (`pip install tunesynctool`).

## Configuration

Configuration options can be loaded from the environment or be manually specified in code. [Check here](https://github.com/WilliamNT/tunesynctool/wiki/Configuration) for more information.

# FAQ

## Is there a way to use tunesynctool from the CLI?
Yes, see the wiki.

## Does this package offer functionality to download or stream music?
**No**, use the official clients for that.

## How does matching work?

Learn more about matching [here](https://github.com/WilliamNT/tunesynctool/wiki/Track-matching).
